# Model Changelog

Please record the following for each model:

- Initials of the contributor
- Subfolder name
- Date of introduction
- Summary of changes compared to previous versions

---

## 13/11/2026 Model Update - Binary Classifier v2.0.0

**Author : Daniele Lotito** **Changes:**

- Trained on updated lakehouse data (includes `granite-4.0` models, data up to
  30th October 2025).
- Same dependencies as previous version.

**Location : `v2-0-0_ag-20251113_154241-refit-clone-opt`**

## 12/11/2026 Model Update - Binary Classifier v1.1.0

**Author: Daniele Lotito** **Changes:**

- Removed dependencies on `limbomp` and `fastai`.
- No changes to model size, datasets, or performance.
- Requires PyTorch

**Location:`v1-1-0_ag-20251112_155927-refit-clone-opt`**
